Index: webrtc/pc/dtmfsender.cc |
diff --git a/webrtc/pc/dtmfsender.cc b/webrtc/pc/dtmfsender.cc |
index bbb100ea61789d3b295170131793af258c8ec3cb..a08a53ce0e59dbd4a2ede5c4e3574a5338d6e245 100644 |
--- a/webrtc/pc/dtmfsender.cc |
+++ b/webrtc/pc/dtmfsender.cc |
@@ -39,10 +39,10 @@ static const int kDtmfCodeTwoSecondDelay = -1; |
static const int kDtmfTwoSecondInMs = 2000; |
static const char kDtmfValidTones[] = ",0123456789*#ABCDabcd"; |
static const char kDtmfTonesTable[] = ",0123456789*#ABCD"; |
// The duration cannot be more than 6000ms or less than 70ms. The gap between |
// tones must be at least 50 ms. |
static const int kDtmfDefaultDurationMs = 100; |
-static const int kDtmfMinDurationMs = 70; |
+static const int kDtmfMinDurationMs = 40; |
static const int kDtmfMaxDurationMs = 6000; |
static const int kDtmfDefaultGapMs = 50; |
static const int kDtmfMinGapMs = 50; |
@@ -39,10 +39,10 @@ static const int kDtmfCodeTwoSecondDelay = -1; |
static const char kDtmfValidTones[] = ",0123456789*#ABCDabcd"; |
static const char kDtmfTonesTable[] = ",0123456789*#ABCD"; |
-// The duration cannot be more than 6000ms or less than 70ms. The gap between |
+// The duration cannot be more than 6000ms or less than 40ms. The gap between |
// tones must be at least 50 ms. |
static const int kDtmfDefaultDurationMs = 100; |